pub type SqlType = (Text, Integer, Integer, Integer, Integer, Integer);Expand description
The SQL type of all of the columns on this table
pub type SqlType = (Text, Integer, Integer, Integer, Integer, Integer);The SQL type of all of the columns on this table